@@ -86,7 +86,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             if self.data.get('condiciones_pago'):
                 dom.setAttribute('CondicionesDePago', self.data.get('condiciones_pago'))
 
-            if self.data.get('descuento'):
+            if self.data.get('descuento') not in ['0', '0.00', '0.000000']:
                 dom.setAttribute('Descuento', self.data.get('descuento'))
 
             dom.setAttribute('MetodoPago', self.data.get('metodo_pago'))
